# BEGIN COPYRIGHT BLOCK
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
# (C) 2007 Red Hat, Inc.
# All rights reserved.
# END COPYRIGHT BLOCK

###############################################################################
###                          D E F I N I T I O N S                          ###
###############################################################################

## Entity Definitions
%define base_entity       Red Hat
%define base_prefix       pki

## Product Definitions
%define base_system       Certificate System
%define base_product      PKI Selinux Policies
%define base_component    selinux
%define base_pki          %{base_entity} %{base_system}

## Package Header Definitions
%define base_name         %{base_prefix}-%{base_component}
%define base_version      8.1.3
%define base_release      1
%define base_phase        %{nil}
%define base_group        System Environment/Shells
%define base_vendor       Red Hat, Inc.
%define base_license      GPLv2 with exceptions
%define base_packager     %{base_vendor} <http://bugzilla.redhat.com/bugzilla>
%define base_summary      %{base_pki} - %{base_product}
%define base_url          http://www.redhat.com/certificate_system

## Helper Definitions
%define pki_ca            %{base_entity} Certificate Authority
%define pki_drm           %{base_entity} Data Recovery Manager
%define pki_ds            %{base_entity} Directory Server
%define pki_ocsp          %{base_entity} Online Certificate Status Protocol Manager
%define pki_ra            %{base_entity} Registration Authority
%define pki_tks           %{base_entity} Token Key Service
%define pki_tps           %{base_entity} Token Processing System

## Don't build the debug packages
%define debug_package     %{nil}


##===================##
## Linux Definitions ##
##===================##
%ifos Linux
## A distribution model is required on certain Linux operating systems!
##
## check for a pre-defined distribution model
%define undefined_distro  %(test "%{dist}" = "" && echo 1 || echo 0)
%if %{undefined_distro}
%define is_fedora         %(test -e /etc/fedora-release && echo 1 || echo 0)
%if %{is_fedora}
## define a default distribution model on Fedora Linux
%define dist_prefix       .fc
%define dist_version      %(echo `rpm -qf --qf='%{VERSION}' /etc/fedora-release` | tr -d [A-Za-z])
%define dist              %{dist_prefix}%{dist_version}
%else
%define is_redhat         %(test -e /etc/redhat-release && echo 1 || echo 0)
%if %{is_redhat}
## define a default distribution model on Red Hat Linux
%define dist_prefix       .el
%define dist_version      %(echo `rpm -qf --qf='%{VERSION}' /etc/redhat-release` | tr -d [A-Za-z])
%define dist              %{dist_prefix}%{dist_version}
%endif
%endif
%endif
%endif



###############################################################################
###                       P A C K A G E   H E A D E R                       ###
###############################################################################

Name:           %{base_name}
Version:        %{base_version}
Release:        %{base_release}%{?base_phase}%{?dist}
Summary:        %{base_summary}
Vendor:         %{base_vendor}
URL:            %{base_url}
License:        %{base_license}
Packager:       %{base_packager}
Group:          %{base_group}


## Without AutoReqProv: no, rpmbuild finds all sorts of crazy
## dependencies that we don't care about, and refuses to install
AutoReqProv:    no

BuildArch:      noarch
BuildRoot:      %{_builddir}/%{base_name}-root


## NOTE:  This spec file may require a specific JDK, "gcc", and/or "gcc-c++"
##        packages as well as the "rpm" and "rpm-build" packages.
##
##        Technically, "ant" should not need to be in "BuildRequires" since
##        it is the Java equivalent of "make" (and/or "Autotools").
##
BuildRequires:  ant >= 1.6.5, selinux-policy-devel, m4, make, policycoreutils

## Without Requires something, rpmbuild will abort!
##
## We require selinux-policy-targeted here, because this rpm will also deliver
## pki.pp to /usr/share/selinux/targeted/pki.pp.  It is to be removed in subsequent releases.
## If selinux-policy-targeted is installed after pki-selinux, semodule will overwrite the
## policy delivered in this rpm
Requires:       policycoreutils, libsemanage, selinux-policy-targeted >= 2.4.6-300


## This package is non-relocatable!
#Prefix:

Source0:        %{base_name}-%{base_version}.tar.gz

## This package currently contains no patches!
#Patch0:


%description
Selinux policies for the Pubic Key Infrastructure (PKI) components.



###############################################################################
###                  P R E P A R A T I O N   &   S E T U P                  ###
###############################################################################

## On Linux systems, prep and setup expect there to be a Source file
## in the /usr/src/redhat/SOURCES directory - it will be unpacked
## in the _builddir (not BuildRoot)
%prep


%setup -q -n %{base_name}-%{base_version}


## This package currently contains no patches!
#%patch0
# patches



###############################################################################
###                        B U I L D   P R O C E S S                        ###
###############################################################################

%build
cd src
make



###############################################################################
###                 I N S T A L L A T I O N   P R O C E S S                 ###
###############################################################################

%install
rm -rf ${RPM_BUILD_ROOT}
mkdir -p ${RPM_BUILD_ROOT}%{_datadir}/doc/%{base_name}-%{base_version}
cp -p EULA ${RPM_BUILD_ROOT}%{_datadir}/doc/%{base_name}-%{base_version}
chmod 00644 ${RPM_BUILD_ROOT}%{_datadir}/doc/%{base_name}-%{base_version}/EULA
cp -p LICENSE ${RPM_BUILD_ROOT}%{_datadir}/doc/%{base_name}-%{base_version}
chmod 00644 ${RPM_BUILD_ROOT}%{_datadir}/doc/%{base_name}-%{base_version}/LICENSE
mkdir -p ${RPM_BUILD_ROOT}%{_datadir}/selinux/modules
cp -p src/pki.pp ${RPM_BUILD_ROOT}%{_datadir}/selinux/modules



###############################################################################
###                      C L E A N U P   P R O C E S S                      ###
###############################################################################

%clean
rm -rf ${RPM_BUILD_ROOT}



###############################################################################
###  P R E  &  P O S T   I N S T A L L / U N I N S T A L L   S C R I P T S  ###
###############################################################################

%define saveFileContext() \
if [ -s /etc/selinux/config ]; then \
        . %{_sysconfdir}/selinux/config; \
        FILE_CONTEXT=%{_sysconfdir}/selinux/%1/contexts/files/file_contexts; \
        if [ "${SELINUXTYPE}" == %1 -a -f ${FILE_CONTEXT} ]; then \
                cp -f ${FILE_CONTEXT} ${FILE_CONTEXT}.%{name}; \
        fi \
fi;

%define relabel() \
. %{_sysconfdir}/selinux/config; \
FILE_CONTEXT=%{_sysconfdir}/selinux/%1/contexts/files/file_contexts; \
selinuxenabled; \
if [ $? == 0  -a "${SELINUXTYPE}" == %1 -a -f ${FILE_CONTEXT}.%{name} ]; then \
        fixfiles -C ${FILE_CONTEXT}.%{name} restore; \
        rm -f ${FILE_CONTEXT}.%name; \
fi;

%pre
%saveFileContext targeted

%post
semodule -s targeted -i /usr/share/selinux/modules/pki.pp 
%relabel targeted

%preun
if [ $1 = 0 ]; then
%saveFileContext targeted
fi

%postun
if [ $1 = 0 ]; then
semodule -s targeted -r pki
%relabel targeted
fi

###############################################################################
###   I N V E N T O R Y   O F   F I L E S   A N D   D I R E C T O R I E S   ### 
###############################################################################

%files
%attr(-,root,root)     %{_datadir}/doc/%{base_name}-%{base_version}/*
%attr(-,root,root)     %{_datadir}/selinux/modules/pki.pp



###############################################################################
###                            C H A N G E L O G                            ###
###############################################################################

%changelog
* Tue Feb 3 2015 Ade Lee <alee@redhat.com> 8.1.3-1
- Bugzilla Bug #1186037 - selinux fix for latest ncipher software

* Thu Mar 24 2011 Matthew Harmsen <mharmsen@redhat.com> 8.1.0-2
- Bugzilla Bug #690646 - Update Build and Runtime Dependencies for RHCS 8.1

* Tue Jan 12 2010 Matthew Harmsen <mharmsen@redhat.com> 8.1.0-1
- Bump to version 8.1.0

* Mon Nov 9 2009 Ade Lee <alee@redhat.com> 8.0.0-11
- Bugzilla Bug #518123 - Prompt for passwords if password.conf is removed

* Mon Jul 13 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-10
- Bugzilla Bug #511136 -  Integrate EULA file into RHCS
- Release Candidate 4 build

* Wed Jul 8 2009 Kevin Wright <kwright@redhat.com> 8.0.0-9
- Bugzilla Bug #510352 -  Release Candidate 3 build

* Thu Jul 2 2009 Kevin Wright <kwright@redhat.com> 8.0.0-8
- Bugzilla Bug #509447 -  Release Candidate 2 build

* Thu Jun 25 2009 Kevin Wright <kwright@redhat.com> 8.0.0-7
- Bugzilla Bug #508179 -  Remove base_phase ".beta" tag

* Mon May 4 2009 Kevin Wright <kwright@redhat.com> 8.0.0-6
- Bugzilla Bug #499030 -  Beta 2 Release

* Fri May 1 2009 Ade Lee <alee@redhat.com> 8.0.0-5
- Bugzilla Bug #495157 -  SELinux prevents CA from using nethsm pkcs11 module

* Fri Mar 27 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-4
- Bugzilla Bug #492502 -  Redefine "base_phase" from ".alpha" to ".beta"

* Sat Feb 28 2009 Matthew Harmsen <mharmsen@redhat.com> 8.0.0-3
- Bugzilla Bug #487896 - Introduce optional 'base_phase' release tag to
  denote ".alpha", ".beta", etc.

* Thu Jan 29 2009 Ade Lee <alee@redhat.com> 8.0.0-2
-  Bugzilla Bug #483134 Moved selinux to /usr/share/selinux/modules, update dependencies
* Wed Jan 21 2009 Ade Lee <alee@redhat.com> 8.0.0-1
- Bugzilla Bug #480679 - integrate latest selinux code with the rest
  of the build infrastructure 
- Initial release

